@@ -20,12 +20,10 @@ BEGIN {
    $perl_ver = $notes->{min_perl_version} || 5.008;
 
    if ($notes->{testing}) {
-      $Bin =~ m{ : .+ : }mx and
-         plan skip_all => 'Two colons in $Bin path';
-      $host eq 'digitalis'  and
-         plan skip_all => 'Broken smoker a54c1c84-6bf5-1014-b4f9-dcd54300afcd';
-      # TODO: Remove this when service is restored
-      plan skip_all => 'CPAN Testing down Aug 2015';
+      $Bin =~ m{ : .+ : }mx and plan
+         skip_all => 'Two colons in $Bin path';
+      $host eq 'digitalis' and plan
+         skip_all => 'Broken smoker a54c1c84-6bf5-1014-b4f9-dcd54300afcd';
    }
 }
 
